News for hackers. Stuff that matters.
Re:CSV Reader Benchmarks: Julia Reads CSVs 10-20x Faster tha... by orbifold on Sunday October 11, 2020 @07:22PM (#24749979)
time to precompile Plots: 138s

julia> @time Plots.scatter(data.eq_site_limit, data.hu_site_limit) 5.461595 seconds

subsequent calls report significant speed ups compared to matplotlib, but render about as quickly

julia> @time Plots.histogram(data.eq_site_limit) 2.143983 seconds

Re:CSV Reader Benchmarks: Julia Reads CSVs 10-20x Faster tha... by ViralBShah on Sunday October 11, 2020 @09:14PM (#24750559)
There are 3 different phases:

1. Precompilation time: Only once when you install or upgrade a package.

2. First running time (that includes compilation time): When you call a function like `plot` the first time in a session

3. Second and subsequent running times: The compiled code is now in the cache, and what you see is the actual running time.

Thus what you are reporting here as precompilation (1) is not something that a user will see every time. What they will see is (2) for the first time in a session and (3) on subsequent plots. Could you confirm this is what you see - to ensure that those following along understand the terminology?

Here are the usage times I see when I use Plots on a daily basis in a Julia session:

  ~ exec '/Users/viral/Desktop/Julia_Releases/Julia-1.5.app/Contents/Resources/julia/bin/julia'
               _
   _       _ _(_)_     |  Documentation: https://docs.julialang.org
  (_)     | (_) (_)    |
   _ _   _| |_  __ _   |  Type "?" for help, "]?" for Pkg help.
  | | | | | | |/ _` |  |
  | | |_| | | | (_| |  |  Version 1.5.2 (2020-09-23)
 _/ |\__'_|_|_|\__'_|  |  Official https://julialang.org/ release
|__/ |

   julia> @time using Plots
   11.341632 seconds (20.21 M allocations: 1.108 GiB, 2.87% gc time)

   julia> @time plot(1:10,1:10)
   2.291147 seconds (3.24 M allocations: 165.569 MiB, 7.80% gc time)
   (Another 2 seconds for the window to be drawn the first time on mac)

   julia> @time plot(1:10,1:10)
   0.000763 seconds (2.80 k allocations: 166.023 KiB)